package com.persagy.dmp.rwd.basic.utils;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.amqp.handler.RabbitMessageSender;
import com.persagy.dmp.basic.model.DigitalManageMessage;
import com.persagy.dmp.basic.utils.JsonNodeUtils;
import com.persagy.dmp.common.constant.ResponseCode;
import com.persagy.dmp.common.exception.BusinessException;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.constant.DigitalMessageConstant;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 数据孪生消息发送助手
 * @author Charlie Yu
 * @date 2021-06-25
 */
@Component
public class DigitalMessageHelper {

    @Autowired
    private RabbitMessageSender messageSender;
    @Autowired
    private ObjectMapper objectMapper;

    /**
     * 发送消息
     * @param operator 操作类型
     * @param oldVO 原数据
     * @param newVO 现数据
     * @param syncFlag 同步消息标识
     */
    public void sendMessage(String operator, BaseEntity oldVO, BaseEntity newVO, boolean syncFlag) {
        DigitalManageMessage message = new DigitalManageMessage();
        message.setOperatorType(operator);
        message.setOperatorObj(newVO.getClass().getSimpleName());
        ObjectNode newNode = JsonNodeUtils.toObjectNode(newVO, "infos", null);
        ObjectNode oldNode = JsonNodeUtils.toObjectNode(newVO, "infos", null);
        message.setOldObj(oldNode);
        message.setNewObj(newNode);

        String json = "";
        try {
            json = objectMapper.writeValueAsString(message);
        } catch (JsonProcessingException e) {
            throw new BusinessException(ResponseCode.A0427.getCode(), ResponseCode.A0427.getDesc());
        }
        // 同步消息
        if(syncFlag) {
            messageSender.sendAndReceive(DigitalMessageConstant.MESSAGE_EXCHANGE,
                    DigitalMessageConstant.MESSAGE_ROUTING,
                    json);
        } else {
            // 异步消息
            messageSender.send(DigitalMessageConstant.MESSAGE_EXCHANGE,
                    DigitalMessageConstant.MESSAGE_ROUTING,
                    json);
        }
    }
}
