package com.persagy.dmp.rwd.twin.handler;

import cn.hutool.core.util.StrUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.dmp.amqp.handler.AbstractRabbitHandlerTemplate;
import com.persagy.dmp.basic.model.DigitalManageMessage;
import com.persagy.dmp.basic.utils.JsonNodeUtils;
import com.persagy.dmp.common.constant.CommonConstant;
import com.persagy.dmp.common.context.AppContext;
import com.persagy.dmp.common.exception.BusinessException;
import com.persagy.dmp.mybatis.helper.DynamicDataSourceHelper;
import com.persagy.dmp.rwd.basic.constant.DigitalMessageConstant;
import com.persagy.dmp.rwd.digital.entity.ObjectDigital;
import com.persagy.dmp.rwd.twin.service.IObjectProjectService;
import com.rabbitmq.client.Channel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * 项目消息消费
 * @author lvxianyun
 * @date 2021/8/9
 */
@Slf4j
@Component

@RabbitListener(bindings = @QueueBinding(
        value = @Queue(name = "digital-change-queue", durable = "true"),
        exchange = @Exchange(name = DigitalMessageConstant.MESSAGE_EXCHANGE,
                ignoreDeclarationExceptions = "true"), key = DigitalMessageConstant.MESSAGE_ROUTING
))
public class ObjectMessageHandler extends AbstractRabbitHandlerTemplate {
    @Autowired
    private ObjectMapper objectMapper;
    @Autowired
    private IObjectProjectService objectProjectService;

    /**
     * 消费
     * @param message 消息体字符串
     * @param channel 通道对象
     * @param vo     消息对象
     */
    @Override
    protected void handler(String message, Channel channel, Message vo) {
        try {
            DigitalManageMessage msgVO = objectMapper.readValue(message, DigitalManageMessage.class);
            ObjectNode msgObj = msgVO.getNewObj();
            ObjectDigital currVO = JsonNodeUtils.toEntity(msgObj, ObjectDigital.class, "infos");
            initContextInfo(currVO);
            //处理数据：1.幂等校验； 2.处理数据
            ObjectProcessor.dealObject(currVO.getObjType(),currVO);

        } catch (IOException e) {
             log.error(e.getMessage(), e);
            throw new BusinessException(e.getMessage(), e);
        }
    }

    /**
     * 初始化上下文，切换数据源
     * @param vo
     */
    private void initContextInfo(ObjectDigital vo) {
        AppContext.getContext().setGroupCode(vo.getGroupCode());
        AppContext.getContext().setProjectId(vo.getId());
        AppContext.getContext().setAppId("BOSS");
        String userId = vo.getModifier();
        // 无用户时，默认为默认系统用户
        if(StrUtil.isBlank(userId)) {
            userId = CommonConstant.DEFAULT_ID;
        }
        AppContext.getContext().setAccountId(userId);
        DynamicDataSourceHelper.loadDataSource();
    }
}
