package com.persagy.dmp.rwd.twin.handler;

import cn.hutool.core.map.MapUtil;
import com.persagy.dmp.rwd.basic.constant.DigitalObjectType;
import com.persagy.dmp.rwd.digital.entity.ObjectDigital;

import java.util.HashMap;
import java.util.Map;

/**
 * @author lvxianyun
 * @date 2021/8/10
 */
public class ObjectProcessor {

    private static Map<String, IObjectProcessor> processors = new HashMap<>(16);

    /**
     * 处理数据：1.幂等校验； 2.处理数据
     */
    public static void dealObject(String objType, ObjectDigital vo) {
        getProcessor(objType).dealData(vo);
    }


    private static IObjectProcessor getProcessor(String objType) {
        if(MapUtil.isEmpty(processors) || !processors.containsKey(objType)) {
            putProcessor(objType);
        }
        return processors.get(objType);
    }


    private static void putProcessor(String objType){
        if(DigitalObjectType.PROJECT.getIndex().equals(objType)){
            processors.put(objType, new ObjectProjectProcessor());

        }else if(DigitalObjectType.BUILDING.getIndex().equals(objType)){
            processors.put(objType, new ObjectBuildingProcessor());

        }else if(DigitalObjectType.FLOOR.getIndex().equals(objType)){
            processors.put(objType, new ObjectFloorProcessor());

        }else if(DigitalObjectType.SPACE.getIndex().equals(objType)){
            processors.put(objType, new ObjectSpaceProcessor());

        }else if(DigitalObjectType.EQUIPMENT.getIndex().equals(objType)){
            processors.put(objType, new ObjectEquipmentProcessor());

        }else if(DigitalObjectType.SYSTEM.getIndex().equals(objType)){
            processors.put(objType, new ObjectSystemProcessor());

        }else if(DigitalObjectType.SHAFT.getIndex().equals(objType)){
            processors.put(objType, new ObjectShaftProcessor());
        }else{
            //租户
            processors.put(objType, new ObjectTenantProcessor());
        }
    }

}
