package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectBuildingMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectBuilding;
import com.persagy.dmp.rwd.twin.service.IObjectBuildingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 建筑 接口实现类
 * @author lvxianyun
 * @date 2021/8/13
 */
@Service("objectBuildingServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectBuildingServiceImpl implements IObjectBuildingService {

    @Resource
    private ObjectBuildingMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectBuilding load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectBuilding> queryByCondition(Wrapper<ObjectBuilding> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectBuilding> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectBuilding> insert(List<ObjectBuilding> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectBuilding> update(List<ObjectBuilding> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectBuilding> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectBuilding> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectBuilding dbVO = MapUtil.get(dbMap, vo.getId(), ObjectBuilding.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }

            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectBuilding> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectBuilding> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectBuilding dbVO = MapUtil.get(dbMap, id, ObjectBuilding.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectBuilding vo = new ObjectBuilding();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }

}
