package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectFloorMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectFloor;
import com.persagy.dmp.rwd.twin.service.IObjectFloorService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 楼层 接口实现类
 * @author lvxianyun
 * @date 2021/8/9
 */
@Service("objectFloorServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectFloorServiceImpl implements IObjectFloorService {


    @Resource
    private ObjectFloorMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectFloor load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectFloor> queryByCondition(Wrapper<ObjectFloor> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectFloor> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectFloor> insert(List<ObjectFloor> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectFloor> update(List<ObjectFloor> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectFloor> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectFloor> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectFloor dbVO = MapUtil.get(dbMap, vo.getId(), ObjectFloor.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }

            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectFloor> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectFloor> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectFloor dbVO = MapUtil.get(dbMap, id, ObjectFloor.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectFloor vo = new ObjectFloor();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
