package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectProjectMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectProject;
import com.persagy.dmp.rwd.twin.service.IObjectProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 项目数据 实现类
 * @author lvxianyun
 * @date 2021/8/9
 */
@Service("objectProjectServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectProjectServiceImpl implements IObjectProjectService {

    @Resource
    private ObjectProjectMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectProject load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectProject> queryByCondition(Wrapper<ObjectProject> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectProject> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectProject> insert(List<ObjectProject> voList) {
        if(CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectProject> update(List<ObjectProject> voList) {
        if(CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectProject> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectProject> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectProject dbVO = MapUtil.get(dbMap, vo.getId(), ObjectProject.class);
            // 容错处理
            if(dbVO == null) {
                return;
            }

            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if(CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectProject> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectProject> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectProject dbVO = MapUtil.get(dbMap, id, ObjectProject.class);
            // 容错处理
            if(dbVO == null) {
                return;
            }
            // 删除
            ObjectProject vo = new ObjectProject();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
