package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectShaftMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectShaft;
import com.persagy.dmp.rwd.twin.service.IObjectShaftService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 竖井 实现类
 * @author lvxianyun
 * @date 2021/8/13
 */
@Service("objectShaftService")
@Transactional(rollbackFor = Exception.class)
public class ObjectShaftServiceImpl implements IObjectShaftService {

    @Resource
    private ObjectShaftMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectShaft load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectShaft> queryByCondition(Wrapper<ObjectShaft> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectShaft> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectShaft> insert(List<ObjectShaft> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectShaft> update(List<ObjectShaft> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectShaft> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectShaft> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectShaft dbVO = MapUtil.get(dbMap, vo.getId(), ObjectShaft.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }

            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectShaft> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectShaft> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectShaft dbVO = MapUtil.get(dbMap, id, ObjectShaft.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectShaft vo = new ObjectShaft();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
