package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectSpaceMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectSpace;
import com.persagy.dmp.rwd.twin.service.IObjectSpaceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 空间 接口
 * @author lvxianyun
 * @date 2021/8/9
 */
@Service("objectSpaceServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectSpaceServiceImpl implements IObjectSpaceService {

    @Resource
    private ObjectSpaceMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectSpace load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectSpace> queryByCondition(Wrapper<ObjectSpace> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectSpace> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectSpace> insert(List<ObjectSpace> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectSpace> update(List<ObjectSpace> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectSpace> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectSpace> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectSpace dbVO = MapUtil.get(dbMap, vo.getId(), ObjectSpace.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectSpace> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectSpace> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectSpace dbVO = MapUtil.get(dbMap, id, ObjectSpace.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectSpace vo = new ObjectSpace();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
