package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectSystemMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectSystem;
import com.persagy.dmp.rwd.twin.service.IObjectSystemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 系统 接口实现类
 * @author lvxianyun
 * @date 2021/8/13
 */
@Service("objectSystemServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectSystemServiceImpl implements IObjectSystemService {
    @Resource
    private ObjectSystemMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectSystem load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectSystem> queryByCondition(Wrapper<ObjectSystem> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectSystem> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectSystem> insert(List<ObjectSystem> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectSystem> update(List<ObjectSystem> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectSystem> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectSystem> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectSystem dbVO = MapUtil.get(dbMap, vo.getId(), ObjectSystem.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }

            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectSystem> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectSystem> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectSystem dbVO = MapUtil.get(dbMap, id, ObjectSystem.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectSystem vo = new ObjectSystem();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
