package com.persagy.dmp.rwd.twin.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.map.MapUtil;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.common.constant.ValidEnum;
import com.persagy.dmp.common.model.entity.BaseEntity;
import com.persagy.dmp.rwd.basic.utils.DigitalMessageHelper;
import com.persagy.dmp.rwd.twin.dao.ObjectTenantMapper;
import com.persagy.dmp.rwd.twin.entity.ObjectTenant;
import com.persagy.dmp.rwd.twin.service.IObjectTenantService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 租户 接口实现类
 * @author lvxianyun
 * @date 2021/8/13
 */
@Service("objectTenantServic")
@Transactional(rollbackFor = Exception.class)
public class ObjectTenantServiceImpl implements IObjectTenantService {


    @Resource
    private ObjectTenantMapper dao;
    @Autowired
    private DigitalMessageHelper messageSender;

    @Override
    public ObjectTenant load(String id) {
        return dao.selectById(id);
    }

    @Override
    public List<ObjectTenant> queryByCondition(Wrapper<ObjectTenant> queryWrapper) {
        return dao.selectList(queryWrapper);
    }

    @Override
    public Page queryByCondition(Page page, Wrapper<ObjectTenant> queryWrapper) {
        return dao.selectPage(page, queryWrapper);
    }

    @Override
    public List<ObjectTenant> insert(List<ObjectTenant> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        voList.forEach(vo -> {
            // 生成ID
            //vo.setId(vo.getId());
            // 新增
            dao.insert(vo);
        });
        return voList;
    }

    @Override
    public List<ObjectTenant> update(List<ObjectTenant> voList) {
        if (CollUtil.isEmpty(voList)) {
            return null;
        }
        List<String> idList = CollUtil.getFieldValues(voList, BaseEntity.PROP_ID, String.class);
        List<ObjectTenant> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectTenant> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        voList.forEach(vo -> {
            ObjectTenant dbVO = MapUtil.get(dbMap, vo.getId(), ObjectTenant.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            dao.updateById(vo);
        });
        return voList;
    }

    @Override
    public void delete(List<String> idList) {
        if (CollUtil.isEmpty(idList)) {
            return;
        }
        List<ObjectTenant> dbList = dao.selectBatchIds(idList);
        Map<String, ObjectTenant> dbMap = CollectionUtil.fieldValueMap(dbList, BaseEntity.PROP_ID);
        idList.forEach(id -> {
            ObjectTenant dbVO = MapUtil.get(dbMap, id, ObjectTenant.class);
            // 容错处理
            if (dbVO == null) {
                return;
            }
            // 删除
            ObjectTenant vo = new ObjectTenant();
            vo.setId(id);
            vo.setValid(ValidEnum.FALSE.getType());
            dao.updateById(vo);
        });
    }
}
