CREATE TABLE IF NOT EXISTS `dt_define_type` (
  `id` varchar(40) NOT NULL COMMENT '主键',
  `code` varchar(40) NOT NULL COMMENT '编码-全局唯一',
  `name` varchar(200) NOT NULL COMMENT '名称',
  `alias_code` varchar(40) NOT NULL COMMENT '别名编码, 集团下唯一 ',
  `alias_name` varchar(200) NOT NULL COMMENT '别名名称',
  `obj_type` varchar(40) DEFAULT NULL COMMENT '大类型:项目建筑楼层空间系统设备竖井',
  `group_code` varchar(40) NOT NULL DEFAULT '0' COMMENT '集团编码',
  `project_id` varchar(40) NOT NULL DEFAULT '0' COMMENT '项目id',
  `major_code` varchar(40) DEFAULT NULL COMMENT '专业编码, 上级类型是系统or设备时该字段有值',
  `system_code` varchar(40) DEFAULT NULL COMMENT '系统编码,上级类型是设备时该字段有值,值为系统类型的code',
  `equipment_code` varchar(40) DEFAULT NULL COMMENT '设备编码,上级类型是部件时该字段有值,值为设备类型的code',
  `parent_code` varchar(40) DEFAULT NULL COMMENT '上级类型code,默认为"0"',
  `version` varchar(40) DEFAULT NULL COMMENT '最后修改版本',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_code` (`code`) USING BTREE,
  KEY `idx_alias_code` (`alias_code`) USING BTREE,
  KEY `idx_parent_code` (`parent_code`) USING BTREE,
  KEY `idx_major_code` (`major_code`) USING BTREE,
  KEY `idx_code_1` (`group_code`,`project_id`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='对象类型定义';

CREATE TABLE IF NOT EXISTS `dt_define_info` (
  `id` varchar(40) NOT NULL,
  `code` varchar(100) NOT NULL COMMENT '信息点编码,同类型下唯一,标准驼峰格式',
  `name` varchar(200) DEFAULT NULL COMMENT '信息点名称',
  `alias_code` varchar(100) DEFAULT NULL COMMENT '别名编码',
  `alias_name` varchar(200) DEFAULT NULL COMMENT '别名名称',
  `class_code` varchar(40) DEFAULT NULL COMMENT '类型编码',
  `group_code` varchar(40) NOT NULL DEFAULT '0' COMMENT '集团编码',
  `project_id` varchar(40) NOT NULL DEFAULT '0' COMMENT '项目id',
  `category` varchar(40) DEFAULT NULL COMMENT '信息点分类:静态,脉冲,阶段,时序',
  `first_tag` varchar(40) DEFAULT NULL COMMENT '一级标签',
  `second_tag` varchar(40) DEFAULT NULL COMMENT '二级标签',
  `priority` varchar(10) DEFAULT NULL COMMENT '优先级',
  `input_mode` varchar(40) DEFAULT NULL COMMENT '输入方式',
  `unit` varchar(40) DEFAULT NULL COMMENT '单位',
  `data_type` varchar(40) DEFAULT NULL COMMENT '数据类型',
  `is_multiple` int(11) DEFAULT NULL COMMENT '是否复数',
  `is_region` int(11) DEFAULT NULL COMMENT '是否区间',
  `formater` varchar(40) DEFAULT NULL COMMENT '数据格式',
  `data_source` json DEFAULT NULL COMMENT '数据源取值范围/枚举值清单等,根据dataType有不同的内容',
  `remark` text COMMENT '备注',
  `sub_flag` int(11) DEFAULT NULL COMMENT '子分类标记:是否可以按此信息点进行子分类替换,同一类型下目前只支持一个子分类信息点',
  `weak_point` int(11) DEFAULT NULL COMMENT '虚点',
  `show_order` int(11) DEFAULT NULL COMMENT '显示顺序',
  `version` varchar(40) DEFAULT NULL COMMENT '最后修改版本',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_class_1` (`class_code`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='信息点定义表';

CREATE TABLE IF NOT EXISTS `dt_define_graph` (
  `id` varchar(40) NOT NULL,
  `code` varchar(40) DEFAULT NULL COMMENT '编码',
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `first_category` varchar(40) DEFAULT NULL COMMENT '一级分类',
  `second_category` varchar(40) DEFAULT NULL COMMENT '二级分类',
  `remark` varchar(255) DEFAULT NULL COMMENT '分类说明',
  `object_types` varchar(255) DEFAULT NULL COMMENT '关系两侧对象类别',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='图类型表';

CREATE TABLE IF NOT EXISTS `dt_define_rel` (
  `id` varchar(40) NOT NULL,
  `code` varchar(40) DEFAULT NULL COMMENT '编码',
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `graph_code` varchar(40) DEFAULT NULL COMMENT '图编码',
  `directional` int(11) DEFAULT NULL COMMENT '边方向性',
  `attribute` varchar(255) DEFAULT NULL COMMENT '边属性',
  `target_objs` varchar(255) DEFAULT NULL COMMENT '主要连接对象',
  `remark` varchar(45) DEFAULT NULL,
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_code` (`code`) USING BTREE,
  KEY `idx_graph_code` (`graph_code`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='边类型表';

CREATE TABLE IF NOT EXISTS `dt_object` (
  `id` varchar(100) NOT NULL,
  `name` varchar(100) DEFAULT NULL COMMENT '对象名称',
  `local_id` varchar(100) DEFAULT NULL COMMENT '对象本地编码',
  `local_name` varchar(100) DEFAULT NULL COMMENT '对象本地名称',
  `group_code` varchar(40) DEFAULT NULL COMMENT '集团编码',
  `project_id` varchar(40) NOT NULL COMMENT '项目id',
  `obj_type` varchar(40) NOT NULL COMMENT '对象分类',
  `class_code` varchar(40) NOT NULL COMMENT '对象类型编码',
  `grouping` int(11) NOT NULL DEFAULT '1' COMMENT '1单个对象,2对象组',
  `infos` json DEFAULT NULL COMMENT '边类型编码',
  `virtual_codes` json DEFAULT NULL COMMENT '虚点清单',
  `create_app` varchar(40) DEFAULT NULL COMMENT '创建应用',
  `update_app` varchar(40) DEFAULT NULL COMMENT '最后更新应用',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_project_1` (`project_id`,`class_code`,`creation_time`) USING BTREE,
  KEY `idx_project_2` (`project_id`,`creation_time`) USING BTREE,
  KEY `idx_project_3` (`project_id`,`modified_time`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='对象实例表';

CREATE TABLE IF NOT EXISTS `dt_relation` (
  `id` varchar(40) NOT NULL,
  `group_code` varchar(40) DEFAULT NULL,
  `project_id` varchar(40) NOT NULL,
  `graph_id` varchar(40) DEFAULT NULL COMMENT '图主键',
  `graph_code` varchar(40) DEFAULT NULL COMMENT '图编码',
  `rel_code` varchar(40) DEFAULT NULL COMMENT '关系编码',
  `rel_value` varchar(50) DEFAULT NULL COMMENT '关系值',
  `obj_from` varchar(60) DEFAULT NULL COMMENT '来源对象',
  `obj_to` varchar(60) DEFAULT NULL COMMENT '目标对象',
  `create_app` varchar(40) DEFAULT NULL COMMENT '创建应用',
  `update_app` varchar(40) DEFAULT NULL COMMENT '最后更新应用',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  KEY `idx_graph_code` (`graph_code`) USING BTREE,
  KEY `idx_1` (`graph_code`,`rel_code`,`obj_from`,`obj_to`,`project_id`) USING BTREE,
  KEY `idx_2` (`graph_id`,`rel_code`,`obj_from`,`obj_to`,`project_id`) USING BTREE,
  KEY `idx_3` (`graph_code`,`rel_code`,`obj_to`,`project_id`) USING BTREE,
  KEY `idx_4` (`graph_id`,`rel_code`,`obj_to`,`project_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='关系实例表';


CREATE TABLE IF NOT EXISTS `dt_object_project` (
  `id` varchar(64) NOT NULL,
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `password` varchar(60) DEFAULT NULL COMMENT '项目密码',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint DEFAULT 1 COMMENT '合法标识:0-无效，1-有效',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='项目';


CREATE TABLE IF NOT EXISTS `dt_object_building` (
  `id` varchar(64) NOT NULL,
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(40) NOT NULL COMMENT '项目ID',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint DEFAULT 1 COMMENT '合法标识:0-无效，1-有效',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='建筑';


CREATE TABLE IF NOT EXISTS `dt_object_floor` (
  `id` varchar(64) NOT NULL,
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(64) NOT NULL COMMENT '项目ID',
  `building_id` varchar(64) DEFAULT NULL COMMENT '建筑ID',
  `sequence_id` int DEFAULT NULL COMMENT '楼层顺序号',
  `sign` int DEFAULT NULL COMMENT '楼层平面图分割标记',
  `model_id` varchar(64) DEFAULT NULL COMMENT '模型文件ID',
  `outline` json DEFAULT NULL COMMENT '楼层选定区域轮廓线',
  `qr_code` varchar(300) DEFAULT NULL COMMENT '二维码图片',
  `floor_elevation` int DEFAULT NULL COMMENT '楼板标高',
  `bim_id_pre` varchar(200) DEFAULT NULL COMMENT 'BIMID前缀',
  `properties` json DEFAULT NULL COMMENT '自定义信息点',
  `bim_location` varchar(200) DEFAULT NULL COMMENT '坐标',
  `floor_elevation` int(11) DEFAULT NULL COMMENT '人数',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint DEFAULT 1 COMMENT '合法标识:0-无效，1-有效',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='楼层';


CREATE TABLE IF NOT EXISTS `dt_object_space` (
  `id` varchar(64) NOT NULL,
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(64) NOT NULL COMMENT '项目ID',
  `building_id` varchar(64) DEFAULT NULL COMMENT '建筑ID',
  `floor_id` varchar(64) DEFAULT NULL COMMENT '楼层ID',
  `outline` json DEFAULT NULL COMMENT '楼层选定区域轮廓线',
  `outline2` json DEFAULT NULL COMMENT '轮廓线2',
  `pic` json DEFAULT NULL COMMENT '图片',
  `proj_room_func_type` varchar(200) DEFAULT NULL COMMENT '项目空间功能区类型',
  `room_serial` float DEFAULT NULL COMMENT '空间序号',
  `default_qr_code` varchar(200) DEFAULT NULL COMMENT '平台二维码',
  `bim_location` varchar(200) DEFAULT NULL COMMENT '模型中坐标',
  `depth` float DEFAULT NULL COMMENT '进深',
  `width` float DEFAULT NULL COMMENT '面宽',
  `build_area` float DEFAULT NULL COMMENT '建筑面积',
  `net_area` float DEFAULT NULL COMMENT '使用面积',
  `height` float DEFAULT NULL COMMENT '高',
  `intro` text DEFAULT NULL COMMENT '备注文字',
  `elec_cap` float DEFAULT NULL COMMENT '配电容量',
  `pollution_degree` varchar(200) DEFAULT NULL COMMENT '污染等级',
  `func_type` varchar(200) DEFAULT NULL COMMENT '空间功能区类型',
  `tenant_info` json DEFAULT NULL COMMENT '租户信息',
  `dynamic_infor` json DEFAULT NULL COMMENT '动态信息',
  `zone_orientation` varchar(200) DEFAULT NULL COMMENT '空间朝向',
  `rated_coolingp` float DEFAULT NULL COMMENT '设计供冷功率',
  `rated_heatingp` float DEFAULT NULL COMMENT '设计供热功率',
  `ac_type` varchar(200) DEFAULT NULL COMMENT '空调形式',
  `rated_lightp` float DEFAULT NULL COMMENT '设计照明功率',
  `zone_type` varchar(200) DEFAULT NULL COMMENT '内外区分类',
  `state` tinyint DEFAULT 1 COMMENT '空间是否受影响:0不受影响，1受影响',
  `tenant_type` varchar(200) DEFAULT NULL COMMENT '租赁业态类型',
  `tenant` varchar(200) DEFAULT NULL COMMENT '所属租户',
  `qr_code_pic` varchar(200) DEFAULT NULL COMMENT '空间二维码',
  `permanent_people_num` int DEFAULT NULL COMMENT '空间常驻人数',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint DEFAULT 1 COMMENT '合法标识:0-无效，1-有效',
  `creator` varchar(32) DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `ts` timestamp default current_timestamp on update current_timestamp NOT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='空间';


CREATE TABLE IF NOT EXISTS `dt_object_equipment` (
  `id` varchar(64) NOT NULL,
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) DEFAULT NULL COMMENT '集团编码',
  `project_id` varchar(64) DEFAULT NULL COMMENT '项目ID',
  `building_id` varchar(64) DEFAULT NULL COMMENT '建筑ID',
  `bim_location` varchar(200) DEFAULT NULL COMMENT '坐标',
  `qr_code` varchar(300) DEFAULT NULL COMMENT '二维码图片',
  `cad_id`varchar(200) DEFAULT NULL COMMENT '设计图纸中编码',
  `parent_id` varchar(64) DEFAULT NULL COMMENT '部件关联设备的id',
  `property_id` varchar(64) DEFAULT NULL COMMENT '资产id',
  `location` json DEFAULT NULL COMMENT '坐标x,y,z',
  `category_name` varchar(200) DEFAULT NULL COMMENT '分类名',
  `custom_category` varchar(200) DEFAULT NULL COMMENT '项目自定义类型',
  `task_state` tinyint DEFAULT NULL COMMENT '任务状态',
  `model_id` varchar(200) DEFAULT NULL COMMENT '模型id',
  `code_type` int DEFAULT NULL COMMENT '贴码状态',
  `equip_serial` int DEFAULT NULL COMMENT '设备序号',
  `family_name` varchar(200) DEFAULT NULL COMMENT 'Revit族',
  `family_symbol` varchar(200) DEFAULT NULL COMMENT 'Revit族类型',
  `note` text DEFAULT NULL COMMENT '备注',
  `bim_type_id` varchar(200) DEFAULT NULL COMMENT 'BIM构建编码',
  `class_code`varchar(200) DEFAULT NULL COMMENT '分类',
  `app_id`varchar(200) DEFAULT NULL COMMENT '客户端id',
  `find_people` varchar(200) DEFAULT NULL COMMENT '添加人员',
  `rf_id` varchar(200) DEFAULT NULL COMMENT 'RFID标识',
  `default_qr_code` varchar(200) DEFAULT NULL COMMENT '平台二维码',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint NOT NULL COMMENT '有效标识',
  `creation_time` char(14) DEFAULT NULL COMMENT '创建时间',
  `creator` varchar(40) DEFAULT NULL COMMENT '创建用户',
  `modified_time` char(14) DEFAULT NULL COMMENT '最后修改时间',
  `modifier` varchar(40) DEFAULT NULL COMMENT '最后修改人',
  `ts` timestamp DEFAULT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='设备';


CREATE TABLE IF NOT EXISTS 'dt_object_system' (
  `id` varchar(64) NOT NULL COMMENT '主键',
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `cad_id` varchar(60) DEFAULT NULL COMMENT 'CADID',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(64) NOT NULL COMMENT '项目ID',
  `building_id` varchar(64) DEFAULT NULL COMMENT '建筑ID',
  `floor_id` varchar(64) DEFAULT NULL COMMENT '楼层id',
  `category_name` varchar(200) DEFAULT NULL COMMENT '分类名',
  `class_code` varchar(200) DEFAULT NULL COMMENT '分类',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint NOT NULL COMMENT '有效标识',
  `creation_time` char(14) DEFAULT NULL COMMENT '创建时间',
  `creator` varchar(40) DEFAULT NULL COMMENT '创建用户',
  `modified_time` char(14) DEFAULT NULL COMMENT '最后修改时间',
  `modifier` varchar(40) DEFAULT NULL COMMENT '最后修改人',
  `ts` timestamp DEFAULT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='系统';


CREATE TABLE IF NOT EXISTS 'dt_object_shaft' (
  `id` varchar(64) NOT NULL COMMENT '主键',
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `bim_location` varchar(200) DEFAULT NULL COMMENT '',
  `bim_id` varchar(60) DEFAULT NULL COMMENT 'BIM模型中编码',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(64) NOT NULL COMMENT '项目ID',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint NOT NULL COMMENT '有效标识',
  `creation_time` char(14) DEFAULT NULL COMMENT '创建时间',
  `creator` varchar(40) DEFAULT NULL COMMENT '创建用户',
  `modified_time` char(14) DEFAULT NULL COMMENT '最后修改时间',
  `modifier` varchar(40) DEFAULT NULL COMMENT '最后修改人',
  `ts` timestamp DEFAULT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='竖井';


CREATE TABLE IF NOT EXISTS 'dt_object_tenant' (
  `id` varchar(64) NOT NULL COMMENT '主键',
  `name` varchar(200) DEFAULT NULL COMMENT '名称',
  `local_id` varchar(60) DEFAULT NULL COMMENT '本地编码',
  `local_name` varchar(200) DEFAULT NULL COMMENT '本地名称',
  `local_id2` varchar(60) DEFAULT NULL COMMENT '本地编码2',
  `local_name2` varchar(200) DEFAULT NULL COMMENT '本地名称2',
  `group_code` varchar(40) NOT NULL COMMENT '集团编码',
  `project_id` varchar(64) NOT NULL COMMENT '项目ID',
  `lease_info` json DEFAULT NULL COMMENT '租赁信息',
  `consumption_info` json DEFAULT NULL COMMENT '能耗信息',
  `dynamic_infor` json DEFAULT NULL COMMENT '动态信息',
  `custom_param` json DEFAULT NULL COMMENT '自定义信息点',
  `infos` json DEFAULT NULL COMMENT '信息点',
  `valid` tinyint NOT NULL COMMENT '有效标识',
  `creation_time` char(14) DEFAULT NULL COMMENT '创建时间',
  `creator` varchar(40) DEFAULT NULL COMMENT '创建用户',
  `modified_time` char(14) DEFAULT NULL COMMENT '最后修改时间',
  `modifier` varchar(40) DEFAULT NULL COMMENT '最后修改人',
  `ts` timestamp DEFAULT NULL COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='租户';
